/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.convert;

import icy.plugin.abstract_.Plugin;
import icy.plugin.interface_.PluginBundled;
import icy.sequence.Sequence;
import icy.sequence.SequenceUtil;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarEnum;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;
import plugins.tprovoost.sequenceblocks.SequenceBlocks;

/**
 * @author thomasprovoost
 */
public class ConvertStack extends Plugin implements SequenceBlock, PluginBundled {
    public enum TypeConversion {
        STACK, TIME
    }

    final protected VarEnum<TypeConversion> type = new VarEnum<>("Type Wanted", TypeConversion.STACK);
    final protected VarSequence inputSequence = new VarSequence("Sequence", null);
    final protected VarSequence outputSequence = new VarSequence("Out", null);

    @Override
    public void run() {
        final Sequence in = inputSequence.getValue();
        if (in == null)
            throw new VarException(inputSequence, "Input sequence is null.");

        try {
            // create a copy as we don't want to modify input
            final Sequence out = SequenceUtil.getCopy(in);
            if (type.getValue() == TypeConversion.TIME)
                SequenceUtil.convertToTime(out);
            else
                SequenceUtil.convertToStack(out);
            outputSequence.setValue(out);
        }
        catch (final InterruptedException e) {
            // nothing to do
        }
    }

    @Override
    public void declareInput(final VarList inputMap) {
        inputMap.add("sequence", inputSequence);
        inputMap.add("Type Wanted", type);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        outputMap.add("out", outputSequence);
    }

    @Override
    public String getMainPluginClassName() {
        return SequenceBlocks.class.getName();
    }

}
