/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.convert;

import icy.image.IcyBufferedImageUtil.FilterType;
import icy.plugin.abstract_.Plugin;
import icy.plugin.interface_.PluginBundled;
import icy.sequence.Sequence;
import icy.sequence.SequenceUtil;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarBoolean;
import plugins.adufour.vars.lang.VarEnum;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;
import plugins.tprovoost.sequenceblocks.SequenceBlocks;

import javax.swing.*;

public class Resize extends Plugin implements SequenceBlock, PluginBundled {
    protected enum Proportional {
        NO, TO_WIDTH, TO_HEIGHT
    }

    final protected VarSequence EZseq = new VarSequence("Sequence", null);
    final protected VarInteger EZsizew = new VarInteger("Width", 320);
    final protected VarInteger EZsizeh = new VarInteger("Height", 200);
    final protected VarEnum<Proportional> EZproportional = new VarEnum<>("Proportional", Proportional.NO);
    final protected VarBoolean EZscale = new VarBoolean("Scale content", Boolean.TRUE);
    final protected VarEnum<FilterType> EZtype = new VarEnum<>("Filter", FilterType.BICUBIC);
    final protected VarSequence varOut = new VarSequence("Out", null);

    @Override
    public void run() {
        final Sequence s;
        int w, h;
        final FilterType type;

        // EZ PLUG
        s = EZseq.getValue();
        w = EZsizew.getValue();
        h = EZsizeh.getValue();
        type = EZtype.getValue();

        if (s == null || w <= 0 || h <= 0)
            throw new VarException(null, "No sequence chosen for resize, or wrong size.");

        final double scale = 1d * s.getWidth() / s.getHeight();
        switch (EZproportional.getValue()) {
            case NO:
                break;
            case TO_WIDTH:
                h = (int) (w / scale);
                break;
            case TO_HEIGHT:
                w = (int) (scale * h);
                break;
        }

        if (EZscale.getValue())
            varOut.setValue(SequenceUtil.scale(s, w, h, type));
        else
            varOut.setValue(SequenceUtil.scale(s, w, h, false, SwingConstants.CENTER, SwingConstants.CENTER, type));
    }

    @Override
    public void declareInput(final VarList inputMap) {
        inputMap.add("Sequence", EZseq);
        inputMap.add("Width", EZsizew);
        inputMap.add("Height", EZsizeh);
        inputMap.add("Proportional", EZproportional);
        inputMap.add("Filter", EZtype);
        inputMap.add("Scale content", EZscale);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        outputMap.add("Out", varOut);
    }

    @Override
    public String getMainPluginClassName() {
        return SequenceBlocks.class.getName();
    }
}
