/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.files;

import icy.file.Loader;
import icy.plugin.abstract_.Plugin;
import icy.plugin.interface_.PluginBundled;
import icy.plugin.interface_.PluginLibrary;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarMutable;
import plugins.adufour.vars.lang.VarSequence;
import plugins.tprovoost.sequenceblocks.SequenceBlocks;

import java.io.File;

/**
 * Block to load a Sequence from a file
 *
 * @author Stephane
 */
public class LoadSequence extends Plugin implements SequenceBlock, PluginLibrary, PluginBundled {
    final protected VarMutable f_in = new VarMutable("File", null) {
        @Override
        public boolean isAssignableFrom(final Var source) {
            return (String.class == source.getType()) || (File.class == source.getType());
        }
    };
    final protected VarInteger serie_in = new VarInteger("Series", 0);
    final protected VarSequence outputSequence = new VarSequence("Sequence", null);

    @Override
    public void run() {
        final Object obj = f_in.getValue();
        if (obj != null) {
            final File f;

            if (obj instanceof String)
                f = new File((String) obj);
            else
                f = (File) obj;

            // if (f.isDirectory())
            // throw new VarException("file should not be a directory.");

            outputSequence.setValue(Loader.loadSequence(f.getAbsolutePath(), serie_in.getValue(), false));
        }
    }

    @Override
    public void declareInput(final VarList inputMap) {
        inputMap.add("file", f_in);
        inputMap.add("serie", serie_in);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        outputMap.add("sequence", outputSequence);

    }

    @Override
    public String getMainPluginClassName() {
        return SequenceBlocks.class.getName();
    }
}
