/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.images;

import icy.image.IcyBufferedImage;
import icy.plugin.abstract_.Plugin;
import icy.plugin.interface_.PluginBundled;
import icy.plugin.interface_.PluginLibrary;
import icy.sequence.Sequence;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;
import plugins.tprovoost.sequenceblocks.SequenceBlocks;

/**
 * Set an image at the given [T,Z] position from the Sequence.
 *
 * @author thomasprovoost
 */
public class SetImage extends Plugin implements SequenceBlock, PluginLibrary, PluginBundled {
    Var<IcyBufferedImage> in = new Var<>("Image", IcyBufferedImage.class);
    VarSequence varSeq = new VarSequence("Sequence", null);
    VarInteger imgIdxT = new VarInteger("T", 0);
    VarInteger imgIdxZ = new VarInteger("Z", 0);

    @Override
    public void run() {
        final Sequence s = varSeq.getValue();
        if (s == null)
            throw new VarException(varSeq, "Input sequence is null.");
        s.setImage(imgIdxT.getValue(), imgIdxZ.getValue(), in.getValue());
    }

    @Override
    public void declareInput(final VarList inputMap) {
        inputMap.add("sequence", varSeq);
        inputMap.add("image", in);
        inputMap.add("Idx T", imgIdxT);
        inputMap.add("Idx Z", imgIdxZ);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        //
    }

    @Override
    public String getMainPluginClassName() {
        return SequenceBlocks.class.getName();
    }
}
