/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.importer;

import icy.common.exception.UnsupportedFormatException;
import icy.file.SequenceFileImporter;
import icy.sequence.MetaDataUtil;
import ome.xml.meta.OMEXMLMetadata;

import java.awt.*;
import java.io.IOException;

/**
 * This class allow to use a {@link SequenceFileImporter} while storing a current position information to make its usage
 * more convenient with Protocols.
 *
 * @author Stephane
 */
public class PositionedSequenceFileImporter {
    public SequenceFileImporter importer;
    protected OMEXMLMetadata metadata;
    public int s;
    public int t;
    public int z;
    public int c;
    public Rectangle xyRegion;

    public PositionedSequenceFileImporter(final SequenceFileImporter importer, final OMEXMLMetadata metadata, final int s, final int t, final int z, final int c, final Rectangle xyRegion) {
        super();

        this.importer = importer;
        this.xyRegion = xyRegion;
        this.metadata = metadata;
        this.s = s;
        this.t = t;
        this.z = z;
        this.c = c;
    }

    public PositionedSequenceFileImporter(final SequenceFileImporter importer) {
        this(importer, null, -1, -1, -1, -1, null);
    }

    public PositionedSequenceFileImporter(final PositionedSequenceFileImporter positionedImporter) {
        this(
                positionedImporter.importer,
                positionedImporter.metadata,
                positionedImporter.s,
                positionedImporter.t,
                positionedImporter.z,
                positionedImporter.c,
                positionedImporter.xyRegion
        );
    }

    public OMEXMLMetadata getMetadata() throws UnsupportedFormatException, IOException, InterruptedException {
        // not yet defined --> take it from importer if possible
        if ((metadata == null) && (importer.getOpened() != null)) {
            metadata = importer.getOMEXMLMetaData();
            // clean the metadata
            MetaDataUtil.clean(metadata);
        }

        return metadata;
    }

    @Override
    public String toString() {
        String result;

        if (importer != null)
            result = importer.getClass().getSimpleName();
        else
            result = "No importer";

        if (s != -1)
            result += " S=" + s;
        if (t != -1)
            result += " T=" + t;
        if (z != -1)
            result += " Z=" + z;
        if (c != -1)
            result += " C=" + c;
        if (xyRegion != null)
            result += " XY=" + xyRegion;

        return result;
    }
}
