/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import icy.image.colormap.LinearColorMap;
import icy.plugin.abstract_.Plugin;
import icy.plugin.interface_.PluginBundled;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarColor;
import plugins.tprovoost.sequenceblocks.SequenceBlocks;

import java.awt.*;

/**
 * Block to create a linear colormap from a color value
 *
 * @author Stephane
 * @see SetColormap
 */
public class CreateLinearColormap extends Plugin implements SequenceBlock, PluginBundled {
    private final VarColor color = new VarColor("Color", Color.white);
    private final VarColormap colormap = new VarColormap("Color map", LinearColorMap.gray_);

    @Override
    public void declareInput(final VarList inputMap) {
        inputMap.add("input", color);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        outputMap.add("output", colormap);
    }

    @Override
    public void run() {
        colormap.setValue(new LinearColorMap("color", color.getValue()));
    }

    @Override
    public String getMainPluginClassName() {
        return SequenceBlocks.class.getName();
    }
}
