/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import icy.image.colormap.LinearColorMap;
import icy.plugin.abstract_.Plugin;
import icy.plugin.interface_.PluginBundled;
import icy.sequence.Sequence;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.BlocksException;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarSequence;
import plugins.tprovoost.sequenceblocks.SequenceBlocks;

/**
 * Block to retrieve a channel colormap from a given sequence
 *
 * @author Stephane
 * @see SetColormap
 */
public class GetColormap extends Plugin implements SequenceBlock, PluginBundled {
    private final VarSequence sequenceIn = new VarSequence("Sequence", null);
    private final VarInteger numChannel = new VarInteger("Channel", 0);
    private final VarColormap colormap = new VarColormap("Color map", LinearColorMap.gray_);

    @Override
    public void declareInput(final VarList inputMap) {
        inputMap.add("input", sequenceIn);
        inputMap.add("numChannel", numChannel);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        outputMap.add("output", colormap);
    }

    @Override
    public void run() {
        final Sequence seq = sequenceIn.getValue();

        if (seq != null) {
            final int ch = numChannel.getValue();

            if (ch < seq.getSizeC())
                colormap.setValue(seq.getColorMap(ch));
            else
                throw new BlocksException("Block 'Get Colormap': illegal channel number for this sequence !", true);
        }
    }

    @Override
    public String getMainPluginClassName() {
        return SequenceBlocks.class.getName();
    }
}
