/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import icy.image.colormap.IcyColorMap;
import icy.plugin.abstract_.Plugin;
import icy.plugin.interface_.PluginBundled;
import icy.sequence.Sequence;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarArray;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;
import plugins.tprovoost.sequenceblocks.SequenceBlocks;

import java.util.ArrayList;
import java.util.List;

/**
 * Block to retrieve all channels colormap from a given sequence
 *
 * @author Stephane
 * @see SetColormaps
 */
public class GetColormaps extends Plugin implements SequenceBlock, PluginBundled {
    private final VarSequence sequenceIn = new VarSequence("Sequence", null);
    private final VarArray<IcyColorMap> colormaps = new VarArray<>("Color maps", IcyColorMap[].class, new IcyColorMap[0]);

    @Override
    public void declareInput(final VarList inputMap) {
        inputMap.add("input", sequenceIn);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        outputMap.add("Colormaps", colormaps);
    }

    @Override
    public void run() {
        final Sequence seq = sequenceIn.getValue();
        if (seq == null)
            throw new VarException(sequenceIn, "Sequence is null");

        final List<IcyColorMap> cms = new ArrayList<>();

        for (int c = 0; c < seq.getSizeC(); c++)
            cms.add(seq.getColorMap(c));

        colormaps.setValue(cms.toArray(new IcyColorMap[0]));
    }

    @Override
    public String getMainPluginClassName() {
        return SequenceBlocks.class.getName();
    }
}
