/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import icy.math.UnitUtil;
import icy.plugin.abstract_.Plugin;
import icy.plugin.interface_.PluginBundled;
import icy.sequence.Sequence;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarDouble;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;
import plugins.tprovoost.sequenceblocks.SequenceBlocks;

/**
 * Block to return pixel size and time interval information from a Sequence object.
 *
 * @author Stephane
 * @see ReadMetadata
 * @see GetMetaData
 */
public class GetResolution extends Plugin implements SequenceBlock, PluginBundled {
    final protected VarSequence varSequence = new VarSequence("Sequence", null);
    final protected VarDouble pxSizeX = new VarDouble("Pixel Size X (" + UnitUtil.MICRO_STRING + "m)", 1d);
    final protected VarDouble pxSizeY = new VarDouble("Pixel Size Y (" + UnitUtil.MICRO_STRING + "m)", 1d);
    final protected VarDouble pxSizeZ = new VarDouble("Pixel Size Z (" + UnitUtil.MICRO_STRING + "m)", 1d);
    final protected VarDouble timeIntT = new VarDouble("Time interval T (s)", 0.1d);

    @Override
    public void run() {
        final Sequence s = varSequence.getValue();
        if (s != null) {
            pxSizeX.setValue(s.getPixelSizeX());
            pxSizeY.setValue(s.getPixelSizeY());
            pxSizeZ.setValue(s.getPixelSizeZ());
            timeIntT.setValue(s.getTimeInterval());
        }
        else {
            throw new VarException(varSequence, "Sequence is null");
        }
    }

    @Override
    public void declareInput(final VarList inputMap) {
        inputMap.add("sequence", varSequence);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        outputMap.add("Pixel Size X (" + UnitUtil.MICRO_STRING + "m)", pxSizeX);
        outputMap.add("Pixel Size Y (" + UnitUtil.MICRO_STRING + "m)", pxSizeY);
        outputMap.add("Pixel Size Z (" + UnitUtil.MICRO_STRING + "m)", pxSizeZ);
        outputMap.add("Time interval T (s)", timeIntT);
    }

    @Override
    public String getMainPluginClassName() {
        return SequenceBlocks.class.getName();
    }
}
