/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.loop;

import icy.file.SequenceFileImporter;
import icy.sequence.MetaDataUtil;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.util.VarException;
import plugins.tprovoost.sequenceblocks.importer.PositionedSequenceFileImporter;

import java.util.List;

/**
 * Simple batch loop to iterate over all series from the specified opened {@link SequenceFileImporter} object.
 *
 * @author Stephane
 */
public class SequenceFileImporterSeriesBatch extends SequenceFileImporterBatch {
    @Override
    public void initializeLoop() {
        super.initializeLoop();

        // can take position from element which should have been initialized here
        final PositionedSequenceFileImporter pi = element.getValue();

        try {
            // can iterate over S dimension ?
            if (pi.s == -1)
                limit = MetaDataUtil.getNumSeries(pi.getMetadata());
            else
                limit = 1;
        }
        catch (final Exception e) {
            throw new VarException(element,
                    "Error while initializing SequenceFileImporter series batch: " + e.getMessage());
        }
    }

    @Override
    public void declareInput(final VarList inputMap) {
        super.declareInput(inputMap);

        // we don't want it here
        inputMap.remove(series);
    }

    @Override
    public void declareLoopVariables(final List<Var<?>> loopVariables) {
        super.declareLoopVariables(loopVariables);

        // we don't want it here
        loopVariables.remove(series);
    }

    @Override
    public void beforeIteration() {
        // set current position S
        if (positionedImporter.getValue().s == -1) {
            element.getValue().s = getIterationCounter().getValue();
            // force element changed event so loop get correctly executed
            element.valueChanged(element, element.getValue(), element.getValue());
        }
    }

    @Override
    public boolean isStopConditionReached() {
        return getIterationCounter().getValue() >= limit;
    }
}
