/*
 * Copyright (c) 2010-2023. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.loop;

import icy.file.SequenceFileImporter;
import icy.sequence.MetaDataUtil;
import plugins.adufour.vars.util.VarException;
import plugins.tprovoost.sequenceblocks.importer.PositionedSequenceFileImporter;

/**
 * Simple batch loop to iterate over all Z slice from specified opened {@link SequenceFileImporter} object.
 *
 * @author Stephane
 */
public class SequenceFileImporterSliceBatch extends SequenceFileImporterBatch {
    @Override
    public void initializeLoop() {
        super.initializeLoop();

        // can take position from element which should have been initialized here
        final PositionedSequenceFileImporter pi = element.getValue();

        try {
            // can iterate over Z dimension ?
            if (pi.z == -1)
                limit = MetaDataUtil.getSizeZ(pi.getMetadata(), (pi.s == -1) ? 0 : pi.s);
            else
                limit = 1;
        }
        catch (final Exception e) {
            throw new VarException(element, "Error while initializing SequenceFileImporter slice batch: " + e.getMessage());
        }
    }

    @Override
    public void beforeIteration() {
        // set current position Z
        if (positionedImporter.getValue().z == -1) {
            element.getValue().z = getIterationCounter().getValue();
            // force element changed event so loop get correctly executed
            element.valueChanged(element, element.getValue(), element.getValue());
        }
    }

    @Override
    public boolean isStopConditionReached() {
        return getIterationCounter().getValue() >= limit;
    }
}
